@@ -345,13 +345,10 @@ class BaseDumper(object):
                 self.release_client()
 
     def get_predicates(self):
-        # TODO: can't use this one for parallized dumpers
-        #def no_same_dumper_running(job_manager):
-        #    """
-        #    Avoid collision at file's level (and what's the point anyway?)
-        #    """
-        #    return len([j for j in job_manager.jobs.values() if \
-        #            j["source"] == self.src_name and j["category"] == DUMPER_CATEGORY]) == 0
+        """
+        Return a list of predicates (functions returning true/false, as in math logic)
+        which instructs/dictates if job manager should start a job (process/thread)
+        """
         def no_corresponding_uploader_running(job_manager):
             """
             Don't download data if the associated uploader is running
@@ -1057,19 +1054,19 @@ class GitDumper(BaseDumper):
 
     def _pull(self, localdir, commit):
         # fetch+merge
-        self.logger.info("git pull latest data into '%s'" % localdir)
+        self.logger.info("git pull data (commit %s) into '%s'" % (commit,localdir))
         old = os.path.abspath(os.curdir)
         try:
             os.chdir(localdir)
             # discard changes, we don't want to activate a conflit resolution session...
-            # TODO: origin could be named differently ?
             cmd = ["git", "reset", "--hard", "HEAD"]
             subprocess.check_call(cmd)
+            # then fetch latest code (local repo, not applied to code base yet)
+            cmd = ["git", "fetch", "--all"]
+            subprocess.check_call(cmd)
             if commit != "HEAD":
                 # first get the latest code from repo
                 # (if a newly created branch is avail in remote, we can't check it out)
-                cmd = ["git", "fetch", "--all"]
-                subprocess.check_call(cmd)
                 self.logger.info("git checkout to commit %s" % commit)
                 cmd = ["git", "checkout", commit]
                 subprocess.check_call(cmd)
@@ -1078,6 +1075,9 @@ class GitDumper(BaseDumper):
                 # we need to make sure to go back to master (re-attach)
                 cmd = ["git", "checkout", self.__class__.DEFAULT_BRANCH]
                 subprocess.check_call(cmd)
+                # then merge
+                cmd = ["git", "merge"]
+                subprocess.check_call(cmd)
                 # and then get the commit hash
                 out = subprocess.check_output(["git", "rev-parse", "HEAD"])
                 self.release = "HEAD (%s)" % out.decode().strip()
@@ -1161,6 +1161,19 @@ class DumperManager(BaseSourceManager):
 
     SOURCE_CLASS = BaseDumper
 
+    def get_source_ids(self):
+        """Return displayable list of registered source names (not private)"""
+        # skip private ones starting with __
+        # skip those deriving from bt.h.autoupdate.dumper.BiothingsDumper, they're used for autohub
+        # and considered internal (note: only one dumper per source, so [0])
+        from biothings.hub.autoupdate.dumper import BiothingsDumper
+        registered = sorted([src for src,klasses in self.register.items() if not src.startswith("__") and
+                             not issubclass(klasses[0],BiothingsDumper)])
+        return registered
+
+    def __repr__(self):
+        return "<%s [%d registered]: %s>" % (self.__class__.__name__, len(self.register), self.get_source_ids())
+
     def clean_stale_status(self):
         # not uysing mongo query capabilities as hub backend could be ES, SQLlite, etc...
         # so manually iterate
@@ -1301,7 +1314,7 @@ class DumperManager(BaseSourceManager):
 
     def source_info(self, source=None):
         src_dump = get_src_dump()
-        src_ids = list(self.register.keys())
+        src_ids = self.get_source_ids()
         if source:
             if source in src_ids:
                 src_ids = [source]
