@@ -1,10 +1,8 @@
-import os, asyncio
+import asyncio
 
 from biothings.utils.hub_db import get_data_plugin
 import biothings.hub.dataload.dumper as dumper
 
-from config import logger as logging
-
 
 class GitDataPlugin(dumper.GitDumper):
 
@@ -25,14 +23,13 @@ class ManualDataPlugin(dumper.ManualDumper):
 
     @asyncio.coroutine
     def dump(self, *args, **kwargs):
-        yield from super(ManualDataPlugin,self).dump(
-                path="", # it's the version is original method implemention
-                         # but no version here available
-                release="",*args,**kwargs)
+        yield from super(ManualDataPlugin, self).dump(
+            path="",  # it's the version is original method implemention
+            # but no version here available
+            release="", *args, **kwargs)
 
 
 class DataPluginManager(dumper.DumperManager):
 
     def load(self, plugin_name, *args, **kwargs):
-        return super(DataPluginManager,self).dump_src(plugin_name, *args, **kwargs)
-
+        return super(DataPluginManager, self).dump_src(plugin_name, *args, **kwargs)
